==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/admin/messages/ca/information.php <==
<?php

return [
    'Database' => 'Base de dades',
    'Done' => 'Fet',
    'Error' => 'Error',
    'Logging' => 'Inici de sessió',
    'Never' => 'Mai',
    'Other' => 'Altres',
    'Settings' => 'Configuració',
    '<strong>CronJob</strong> Status' => '',
    '<strong>Queue</strong> Status' => '',
    'About HumHub' => '',
    'Assets' => '',
    'Background Jobs' => '',
    'Base URL' => '',
    'Checking HumHub software prerequisites.' => '',
    'Current limit is: {currentLimit}' => '',
    'Database collation' => '',
    'Database connection time: {dbTime} - Configured time zone: {time}' => '',
    'Database driver - {driver}' => '',
    'Database migration results:' => '',
    'Delayed' => '',
    'Detected URL: {currentBaseUrl}' => '',
    'Displaying {count} entries per page.' => '',
    'Driver' => '',
    'Dynamic Config' => '',
    'Flush entries' => '',
    'HumHub' => '',
    'HumHub is currently in debug mode. Disable it when running on production!' => '',
    'ICU Data Version ({version})' => '',
    'ICU Data {icuMinVersion} or higher is required' => '',
    'ICU Version ({version})' => '',
    'ICU {icuMinVersion} or higher is required' => '',
    'Increase memory limit in {fileName}' => '',
    'Info' => '',
    'Install {phpExtension} Extension' => '',
    'Install {phpExtension} Extension for APC Caching' => '',
    'Install {phpExtension} Extension for DB Caching' => '',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => '',
    'Last run (daily):' => '',
    'Last run (hourly):' => '',
    'Licences' => '',
    'Make {filePath} writable for the Webserver/PHP!' => '',
    'Marketplace API Connection' => '',
    'Memory Limit ({memoryLimit})' => '',
    'Minimum Version {minVersion}' => '',
    'Module Directory' => '',
    'Multibyte String Functions' => '',
    'Optional' => '',
    'Permissions' => '',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => '',
    'Prerequisites' => '',
    'Profile Image' => '',
    'Queue successfully cleared.' => '',
    'Re-Run tests' => '',
    'Recommended collation is {collation}' => '',
    'Recommended collation is {collation} for the tables: {tables}' => '',
    'Recommended engine is {engine} for the tables: {tables}' => '',
    'Reserved' => '',
    'Runtime' => '',
    'Search index rebuild in progress.' => '',
    'Search term...' => '',
    'See installation manual for more details.' => '',
    'Select category..' => '',
    'Select day' => '',
    'Select level...' => '',
    'Supported drivers: {drivers}' => '',
    'Table collations' => '',
    'Table engines' => '',
    'The current main HumHub database name is ' => '',
    'There is a new update available! (Latest version: %version%)' => '',
    'This HumHub installation is up to date!' => '',
    'Time zone' => '',
    'Total {count} entries found.' => '',
    'Trace' => '',
    'Uploads' => '',
    'Varying table engines are not supported.' => '',
    'Version' => '',
    'Waiting' => '',
    'Warning' => '',
    '{imageExtension} Support' => '',
    '{phpExtension} Extension' => '',
    '{phpExtension} Support' => '',
];

==> humhub-1.14.5.tar.gz: humhub-1.14.5/protected/humhub/modules/admin/messages/ca/information.php <==
<?php

return [
    'Base URL' => 'URL base',
    'Database' => 'Base de dades',
    'Done' => 'Fet',
    'Error' => 'Error',
    'Logging' => 'Inici de sessió',
    'Never' => 'Mai',
    'Other' => 'Altres',
    'Permissions' => 'Permisos',
    'Settings' => 'Configuració',
    '<strong>CronJob</strong> Status' => '',
    '<strong>Queue</strong> Status' => '',
    'About HumHub' => '',
    'Assets' => '',
    'Background Jobs' => '',
    'Checking HumHub software prerequisites.' => '',
    'Current limit is: {currentLimit}' => '',
    'Database collation' => '',
    'Database connection time: {dbTime} - Configured time zone: {time}' => '',
    'Database driver - {driver}' => '',
    'Database migration results:' => '',
    'Delayed' => '',
    'Detected URL: {currentBaseUrl}' => '',
    'Disabled Functions' => '',
    'Displaying {count} entries per page.' => '',
    'Driver' => '',
    'Dynamic Config' => '',
    'Flush entries' => '',
    'HumHub' => '',
    'HumHub Documentation' => '',
    'HumHub is currently in debug mode. Disable it when running on production!' => '',
    'ICU Data Version ({version})' => '',
    'ICU Data {icuMinVersion} or higher is required' => '',
    'ICU Version ({version})' => '',
    'ICU {icuMinVersion} or higher is required' => '',
    'Increase memory limit in {fileName}' => '',
    'Info' => '',
    'Install {phpExtension} Extension' => '',
    'Install {phpExtension} Extension for APC Caching' => '',
    'Install {phpExtension} Extension for DB Caching' => '',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => '',
    'Last run (daily):' => '',
    'Last run (hourly):' => '',
    'Licences' => '',
    'Make sure that the `proc_open` function is not disabled.' => '',
    'Make {filePath} writable for the Webserver/PHP!' => '',
    'Marketplace API Connection' => '',
    'Memory Limit ({memoryLimit})' => '',
    'Minimum Version {minVersion}' => '',
    'Module Directory' => '',
    'Multibyte String Functions' => '',
    'Optional' => '',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => '',
    'Prerequisites' => '',
    'Pretty URLs' => '',
    'Profile Image' => '',
    'Queue successfully cleared.' => '',
    'Re-Run tests' => '',
    'Recommended collation is {collation}' => '',
    'Recommended collation is {collation} for the tables: {tables}' => '',
    'Recommended engine is {engine} for the tables: {tables}' => '',
    'Reserved' => '',
    'Runtime' => '',
    'Search index rebuild in progress.' => '',
    'Search term...' => '',
    'See installation manual for more details.' => '',
    'Select category..' => '',
    'Select day' => '',
    'Select level...' => '',
    'Supported drivers: {drivers}' => '',
    'Table collations' => '',
    'Table engines' => '',
    'The current main HumHub database name is ' => '',
    'There is a new update available! (Latest version: %version%)' => '',
    'This HumHub installation is up to date!' => '',
    'Time zone' => '',
    'Total {count} entries found.' => '',
    'Trace' => '',
    'Uploads' => '',
    'Varying table engines are not supported.' => '',
    'Version' => '',
    'Waiting' => '',
    'Warning' => '',
    '{imageExtension} Support' => '',
    '{phpExtension} Extension' => '',
    '{phpExtension} Support' => '',
];
